{comment image from http://csunplugged.org/information-theory/}

Some intermediary text.

{comment explain different views of algorithm (programming context) and Algorithm (that have interesting complexity); use https://www.youtube.com/watch?v=6hfOvs8pY1k for the former?}